# Generated by Django 4.1.7 on 2023-05-29 11:49

import uuid

import django.core.validators
import django.db.models.deletion
import enumfields.fields
from django.db import migrations, models
from enumfields import Enum

import arkindex.process.models
import arkindex.project.aws
import arkindex.project.fields


class GitRefType(Enum):
    Branch = "branch"
    Tag = "tag"


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ("ponos", "0001_initial"),
        ("documents", "0001_initial"),
    ]

    operations = [
        migrations.CreateModel(
            name="CorpusWorkerVersion",
            fields=[
                ("id", models.UUIDField(default=uuid.uuid4, editable=False, primary_key=True, serialize=False)),
            ],
        ),
        migrations.CreateModel(
            name="DataFile",
            fields=[
                ("id", models.UUIDField(default=uuid.uuid4, editable=False, primary_key=True, serialize=False)),
                ("name", models.CharField(max_length=255)),
                ("size", models.PositiveIntegerField(help_text="file size in bytes")),
                ("content_type", models.CharField(max_length=120)),
                ("status", enumfields.fields.EnumField(default="unchecked", enum=arkindex.project.aws.S3FileStatus, max_length=50)),
                ("trashed", models.BooleanField(default=False)),
            ],
            options={
                "ordering": ["corpus", "name"],
            },
            bases=(arkindex.project.aws.S3FileMixin, models.Model),
        ),
        migrations.CreateModel(
            name="GitRef",
            fields=[
                ("id", models.UUIDField(default=uuid.uuid4, editable=False, primary_key=True, serialize=False)),
                ("type", enumfields.fields.EnumField(enum=GitRefType, max_length=10)),
                ("name", models.CharField(max_length=250)),
            ],
        ),
        migrations.CreateModel(
            name="Process",
            fields=[
                ("id", models.UUIDField(default=uuid.uuid4, editable=False, primary_key=True, serialize=False)),
                ("created", models.DateTimeField(auto_now_add=True)),
                ("updated", models.DateTimeField(auto_now=True)),
                ("name", models.CharField(blank=True, max_length=100, null=True)),
                ("mode", enumfields.fields.EnumField(enum=arkindex.process.models.ProcessMode, max_length=30)),
                ("activity_state", enumfields.fields.EnumField(default="disabled", enum=arkindex.process.models.ActivityState, max_length=32)),
                ("name_contains", models.CharField(blank=True, max_length=250, null=True)),
                ("load_children", models.BooleanField(default=False)),
                ("collection_id", models.PositiveIntegerField(blank=True, null=True)),
                ("use_cache", models.BooleanField(default=False)),
                ("use_gpu", models.BooleanField(blank=True, default=False)),
                ("bucket_name", models.CharField(blank=True, max_length=63, null=True, validators=[django.core.validators.MinLengthValidator(3)])),
                ("prefix", models.CharField(blank=True, max_length=1024, null=True)),
            ],
            options={
                "verbose_name_plural": "processes",
                "ordering": ["corpus", "-created"],
            },
        ),
        migrations.CreateModel(
            name="ProcessElement",
            fields=[
                ("id", models.UUIDField(default=uuid.uuid4, editable=False, primary_key=True, serialize=False)),
            ],
        ),
        migrations.CreateModel(
            name="Repository",
            fields=[
                ("id", models.UUIDField(default=uuid.uuid4, editable=False, primary_key=True, serialize=False)),
                ("url", models.URLField(unique=True)),
                ("hook_token", models.CharField(max_length=250, unique=True)),
            ],
            options={
                "verbose_name_plural": "repositories",
            },
        ),
        migrations.CreateModel(
            name="Revision",
            fields=[
                ("created", models.DateTimeField(auto_now_add=True)),
                ("updated", models.DateTimeField(auto_now=True)),
                ("id", models.UUIDField(default=uuid.uuid4, editable=False, primary_key=True, serialize=False)),
                ("hash", models.CharField(max_length=50)),
                ("message", models.TextField()),
                ("author", models.CharField(max_length=50)),
            ],
        ),
        migrations.CreateModel(
            name="Worker",
            fields=[
                ("id", models.UUIDField(default=uuid.uuid4, editable=False, primary_key=True, serialize=False)),
                ("name", models.CharField(max_length=100)),
                ("slug", models.CharField(max_length=100)),
                ("public", models.BooleanField(default=False)),
            ],
        ),
        migrations.CreateModel(
            name="WorkerActivity",
            fields=[
                ("id", models.UUIDField(default=uuid.uuid4, editable=False, primary_key=True, serialize=False)),
                ("created", models.DateTimeField(auto_now_add=True)),
                ("updated", models.DateTimeField(auto_now_add=True)),
                ("started", models.DateTimeField(blank=True, null=True)),
                ("state", enumfields.fields.EnumField(default="queued", enum=arkindex.process.models.WorkerActivityState, max_length=10)),
            ],
        ),
        migrations.CreateModel(
            name="WorkerConfiguration",
            fields=[
                ("id", models.UUIDField(default=uuid.uuid4, editable=False, primary_key=True, serialize=False)),
                ("created", models.DateTimeField(auto_now_add=True)),
                ("updated", models.DateTimeField(auto_now=True)),
                ("name", models.CharField(max_length=250)),
                ("configuration", models.JSONField(default=dict)),
                ("configuration_hash", arkindex.project.fields.MD5HashField(max_length=32)),
                ("archived", models.BooleanField(default=False)),
            ],
        ),
        migrations.CreateModel(
            name="WorkerType",
            fields=[
                ("created", models.DateTimeField(auto_now_add=True)),
                ("updated", models.DateTimeField(auto_now=True)),
                ("id", models.UUIDField(default=uuid.uuid4, editable=False, primary_key=True, serialize=False)),
                ("slug", models.SlugField(max_length=100, unique=True)),
                ("display_name", models.CharField(max_length=100)),
            ],
            options={
                "abstract": False,
            },
        ),
        migrations.CreateModel(
            name="WorkerVersion",
            fields=[
                ("id", models.UUIDField(default=uuid.uuid4, editable=False, primary_key=True, serialize=False)),
                ("configuration", models.JSONField()),
                ("state", enumfields.fields.EnumField(default="created", enum=arkindex.process.models.WorkerVersionState, max_length=10)),
                ("gpu_usage", enumfields.fields.EnumField(blank=True, default="disabled", enum=arkindex.process.models.FeatureUsage, max_length=10)),
                ("model_usage", models.BooleanField(default=False)),
                ("docker_image_iid", models.CharField(blank=True, max_length=80, null=True)),
                ("corpora", models.ManyToManyField(related_name="worker_versions", through="process.CorpusWorkerVersion", to="documents.corpus")),
                ("docker_image", models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to="ponos.artifact")),
                ("revision", models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name="versions", to="process.revision")),
                ("worker", models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name="versions", to="process.worker")),
            ],
        ),
        migrations.CreateModel(
            name="WorkerRun",
            fields=[
                ("id", models.UUIDField(default=uuid.uuid4, editable=False, primary_key=True, serialize=False)),
                ("parents", arkindex.project.fields.ArrayField(base_field=models.UUIDField(), size=None)),
                ("summary", models.TextField()),
                ("configuration", models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name="worker_runs", to="process.workerconfiguration")),
            ],
        ),
    ]
